@@ -133,7 +133,7 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Firefox/3.0.4");
+pref("general.useragent.extra.firefox", "Firefox/3.0.5");
 
 pref("general.smoothScroll", false);
 //@line 180 "/export/home/mozilla/packages/BUILD/mozilla/browser/app/profile/firefox.js"
@@ -526,16 +526,16 @@ pref("browser.safebrowsing.enabled", true);
 pref("browser.safebrowsing.malware.enabled", true);
 
 // Non-enhanced mode (local url lists) URL list to check for updates
-pref("browser.safebrowsing.provider.0.updateURL", "http://safebrowsing.clients.google.com/safebrowsing/downloads?client={moz:client}&appver={moz:version}&pver=2.1");
+pref("browser.safebrowsing.provider.0.updateURL", "http://safebrowsing.clients.google.com/safebrowsing/downloads?client={moz:client}&appver={moz:version}&pver=2.2");
 
 pref("browser.safebrowsing.dataProvider", 0);
 
 // Does the provider name need to be localizable?
 pref("browser.safebrowsing.provider.0.name", "Google");
 pref("browser.safebrowsing.provider.0.lookupURL", "http://safebrowsing.clients.google.com/safebrowsing/lookup?sourceid=firefox-antiphish&features=TrustRank&client={moz:client}&appver={moz:version}&");
-pref("browser.safebrowsing.provider.0.keyURL", "https://sb-ssl.google.com/safebrowsing/newkey?client={moz:client}&appver={moz:version}&pver=2.1");
+pref("browser.safebrowsing.provider.0.keyURL", "https://sb-ssl.google.com/safebrowsing/newkey?client={moz:client}&appver={moz:version}&pver=2.2");
 pref("browser.safebrowsing.provider.0.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/report?");
-pref("browser.safebrowsing.provider.0.gethashURL", "http://safebrowsing.clients.google.com/safebrowsing/gethash?client={moz:client}&appver={moz:version}&pver=2.1");
+pref("browser.safebrowsing.provider.0.gethashURL", "http://safebrowsing.clients.google.com/safebrowsing/gethash?client={moz:client}&appver={moz:version}&pver=2.2");
 
 // privacy policy -- Both url and fallbackurl must exist, although they may
 // point to the same file.  fallbackurl must be a chrome url
@@ -577,15 +577,11 @@ pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.goog
 
 //@line 656 "/export/home/mozilla/packages/BUILD/mozilla/browser/app/profile/firefox.js"
 
-// defaults to true on Windows and Mac, because the installer shows this
-//@line 663 "/export/home/mozilla/packages/BUILD/mozilla/browser/app/profile/firefox.js"
-pref("browser.EULA.3.accepted", false);
-//@line 665 "/export/home/mozilla/packages/BUILD/mozilla/browser/app/profile/firefox.js"
-
-// if we rev the EULA again, we should bump this so users agree to the new EULA
 pref("browser.EULA.version", 3);
+pref("browser.rights.version", 3);
+pref("browser.rights.3.shown", false);
 
-//@line 672 "/export/home/mozilla/packages/BUILD/mozilla/browser/app/profile/firefox.js"
+//@line 665 "/export/home/mozilla/packages/BUILD/mozilla/browser/app/profile/firefox.js"
 
 pref("browser.sessionstore.enabled", true);
 pref("browser.sessionstore.resume_from_crash", true);
